import QtQuick 2.12
import org.ukui.appwidget 1.0


AppWidget {
    id:appWidget
    property real scaling: parent.width==0 ? 1 : parent.width / 448
    property int cardWidth : 448 * scaling
    property int cardHeight : 162 * scaling
    property int temperatureWidth : 98 * scaling
    property int temperatureHeight : 64 * scaling
    property int temperatureFontPixSize : 64 * scaling
    property int weatherInfoHeight : 24 * scaling
    property int weatherInfoSpace : 16 * scaling
    property int weatherInfoFontPixSize : 16 * scaling
    property int weatherInfoTopSpace : 8 * scaling
    property int leftSpace : 24 * scaling
    property int topSpace : 16 * scaling
    property string fontColor : "white"
    property string gsettingPath: "org.kylin-weather.settings"
    property string interfaceKey: "weather"
    property string imageDirPath:"file:///usr/share/kylin-weather/weather-card/background/"
    Rectangle{
        width: cardWidth
        height: cardHeight
        color: "transparent"
        //背景图
        Image {
            id: weatherBackground
            anchors.fill: parent
            source: imageDirPath+"100.png"
        }
        //单指点击、鼠标点击事件
        MouseArea{
            anchors.fill: parent
            onClicked: {

            }
        }
        //温度
        Text {
            id: temperature
            x:leftSpace
            y:topSpace
            width:temperatureWidth
            height:temperatureHeight
            text: qsTr("24°")
            font.pixelSize: temperatureFontPixSize
            color: fontColor
        }
        //城市天气信息
        Text {
            id: weatherInfoCity
            x:leftSpace
            y:temperature.y + temperature.height + weatherInfoTopSpace
            height:weatherInfoHeight
            text: qsTr("长沙市")
            font.pixelSize: weatherInfoFontPixSize
            color: fontColor
        }
        Text {
            id: weatherInfoType
            x:leftSpace
            y:weatherInfoCity.y + weatherInfoHeight + weatherInfoTopSpace
            height:weatherInfoHeight
            text: qsTr("晴天")
            font.pixelSize: weatherInfoFontPixSize
            color: fontColor
        }
        Text {
            id: weatherInfoHumidity
            x:weatherInfoType.x + weatherInfoType.width + weatherInfoSpace
            y:weatherInfoType.y
            height:weatherInfoHeight
            text: qsTr("湿度98%")
            font.pixelSize: weatherInfoFontPixSize
            color: fontColor
        }
        Text {
            id: weatherInfoWind
            x:weatherInfoHumidity.x + weatherInfoHumidity.width + weatherInfoSpace
            y:weatherInfoType.y
            height:weatherInfoHeight
            text: qsTr("东南风一级")
            font.pixelSize: weatherInfoFontPixSize
            color: fontColor
        }
        //简单逻辑
        Item {
            id:logic
            property string gsettingDataStr
            function updateUI (gsettingData){
                gsettingDataStr = gsettingData
                var list = gsettingDataStr.split(',')
                if (list.length < 9) {
                    return noDateUI()
                }
                var datetime = list[0]
                if (datetime.length !== 16) {
                    return noDateUI()
                }
                datetime = new Date(datetime)
                var nowtime = new Date()
                 //1000毫秒=1秒  60秒=1分钟  60分钟=1小时
                var interval = (nowtime - datetime)/1000/60/60
                console.log(datetime,"   ",nowtime,"   ",interval)
                if (interval > 14) { //功能实现了但精度不够，需要天气gsetting接口配合，此处待处理
                    return noDateUI()
                }

                temperature.visible = true
                weatherInfoCity.visible = true
                weatherInfoType.visible = true
                weatherInfoHumidity.visible = true
                weatherInfoWind.visible = true
                temperature.text = list[5]
                weatherInfoCity.text = list[2]
                weatherInfoType.text = list[3]
                weatherInfoHumidity.text = "湿度" + list[4]
                weatherInfoWind.text = list[6] + list[7]
                weatherBackground.source = imageDirPath+list[8]+".png"
                if (weatherBackground.status == Image.Error) {
                    weatherBackground.source = imageDirPath + "100.png"
                }
            }
            function noDateUI (){
                temperature.visible = false
                weatherInfoCity.visible = false
                weatherInfoType.visible = false
                weatherInfoHumidity.visible = false
                weatherInfoWind.visible = false
                weatherBackground.source = imageDirPath+"N-A.png"
            }
        }
        //点击事件
        MouseArea{
            anchors.fill: parent
            onClicked: {
                appWidget.qmlclickedsignal(interfaceKey,"")
            }
        }
        //绑定事件
        Component.onCompleted: {
            creatGsetting(gsettingPath)
            gsettingUpdate.connect(onGsettingUpdate)
            register(interfaceKey,interfaceKey)
            logic.updateUI(getGsettingValue(gsettingPath,interfaceKey))
        }
        function onGsettingUpdate(key, value)
        {
            logic.updateUI(getGsettingValue(gsettingPath,interfaceKey))
        }

    }
}



